==> microjam-0.3.1.tgz: package/docs/index.md <==
---
"layout": "page",
"title": "Creating and Authoring Web Pages with μJam - Introduction",
"description": "Creating Web Pages with `&mu;Jam`",
"tags": ["jamstack","static","serverless","web pages","markdown"],
"use": [ { "uri": "navigation.md" } ],
"permalink": true
---

#  Introduction

## What is it ?

Greek letter `'μ'` is pronounced `'my'` as in `micro`, `'mu'` as in `'music'` or `'mee'` according to [modern Greek](https://www.thoughtco.com/the-greek-alphabet-1705558). In that context here it simply means *tiny* or  *minimalistic*.

That `'Jam'` in &mu;Jam comes from `Jamstack` and means the collection of the three attributes
* **J** avaScript
* **A** PI
* **M** arkup

It is mostly about the creation of static web pages or *serverless* websites and you might want to [read more](https://jamstack.org/) about that modern way to build lightweight web pages [here](https://jamstack.wtf/) and [there](https://jamstack.email/).

## What can I do with it ?

If you want to 
* create a small to medium website
* write down the contents of your web pages in that easy to learn and use [Markdown language](https://commonmark.org/help/)
* publish your web-pages to your GitHub repository and [GitHub pages](https://pages.github.com/)
* do that all from inside free [*Visual Studio Code*](https://code.visualstudio.com/) (`vscode`) editor

then the minimalistic and powerful approach of &mu;Jam might convice you.

## I am not a programmer !

You don't need to be one ... promised.

At first you need to install the free and open source [Visual Studio Code](https://code.visualstudio.com/Download) editor. Chances are you already have it. But you can also do that later.

## Yet another Jamstack Approach ?

Hmm ... there are in fact a [lot static site generators](https://www.staticgen.com/) available and here are [some ways](https://www.netlify.com/blog/2020/04/14/what-is-a-static-site-generator-and-3-ways-to-find-the-best-one/) to find your [best Jamstack approach](https://www.stackbit.com/blog/choosing-your-ssg/).

Many of them

* are highly configurable.
* depend on a certain programming language.
* have fine grained control via command line usage.

So if this is exactly what you want, go on ... I recommend to have a closer look at [Eleventy](https://www.11ty.dev).

> With &mu;Jam I want to offer my mechanical engineering students and a certain number of interested colleagues a tool, which
> *  allows to create small to medium project specific websites.
> *  is easy to learn and use.
> *  does not require web programming skills.
> *  can handle LaTeX math expressions natively,
> *  integrates static or dynamic vector graphics
> *  offers comfortable Html previewing
> *  supports high quality research paper `pdf`-format output.
> *  doing that all inside of a markdown authoring application.
> 
> As a result &mu;Jam is considered a [low code publishing tool](https://en.wikipedia.org/wiki/Low-code_development_platform) for scientists, engineers and students.

In this sense &mu;Jam is minimalistic, as it does quite well, what it is intended to do, but not more. And as you can easily leave that *math*, *vector graphics* and *research paper* stuff out, it may serve your publishing wishes also well.
In this possible case you are invited to read on.

This is my second relevant VSCode extension. My other one is [Markdown+Math](https://marketplace.visualstudio.com/items?itemName=goessner.mdmath).
If you want to know a bit more about myself, you might get a compact overview on my [research gate](https://www.researchgate.net/profile/Stefan_Goessner) profile.

==> microjam-0.3.7.tgz: package/docs/index.md <==
---
"layout": "page",
"title": "Creating and Authoring Web Pages with μJam - Introduction",
"description": "Creating Web Pages with `&mu;Jam`",
"tags": ["jamstack","static","serverless","web pages","markdown"],
"use": [ { "uri": "navigation.md" } ],
"permalink": true
---

#  Introduction

## What is it ?

Greek letter `'μ'` is pronounced `'my'` as in `micro`, `'mu'` as in `'music'` or `'mee'` according to [modern Greek](https://www.thoughtco.com/the-greek-alphabet-1705558). In that context here it simply means *tiny* or  *minimalistic*.

That `'Jam'` in &mu;Jam comes from `Jamstack` and means the collection of the three attributes
* **J** avaScript
* **A** PI
* **M** arkup

It is mostly about the creation of static web pages or *serverless* websites and you might want to [read more](https://jamstack.org/) about that modern way to build lightweight web pages [here](https://jamstack.wtf/) and [there](https://jamstack.email/).

## What can I do with it ?

If you want to 
* create a small to medium website
* write down the contents of your web pages in that easy to learn and use [Markdown language](https://commonmark.org/help/)
* publish your web-pages to your GitHub repository and [GitHub pages](https://pages.github.com/)
* do that all from inside free [*Visual Studio Code*](https://code.visualstudio.com/) (`vscode`) editor

then the minimalistic and powerful approach of &mu;Jam might convice you.

## I am not a programmer !

You don't need to be one ... promised.

At first you need to install the free and open source [Visual Studio Code](https://code.visualstudio.com/Download) editor. Chances are you already have it. But you can also do that later.

## Yet another Jamstack Approach ?

Hmm ... there are in fact a [lot static site generators](https://www.staticgen.com/) available and here are [some ways](https://www.netlify.com/blog/2020/04/14/what-is-a-static-site-generator-and-3-ways-to-find-the-best-one/) to find your [best Jamstack approach](https://www.stackbit.com/blog/choosing-your-ssg/).

Many of them

* are highly configurable.
* depend on a certain programming language.
* have fine grained control via command line usage.

So if this is exactly what you want, go on ... I recommend to have a closer look at [Eleventy](https://www.11ty.dev).

In contrast, **&mu;Jam** is meant to be a minimalistic, [low code publishing](https://en.wikipedia.org/wiki/Low-code_development_platform) tool, which ...

> *  is easy to learn and use.
> *  does not require web programming skills.
> *  can handle LaTeX math expressions natively.
> *  integrates static or dynamic vector graphics.
> *  integrates scripting capabilities.
> *  offers comfortable Html previewing.
> *  supports different templates and styles.
> *  enables high quality research paper `pdf`-format output.
> *  doing that all inside of a professional markdown authoring application.

**&mu;Jam** is used by scientists, engineers and students for creating online educational or [research](https://www.researchgate.net/profile/Stefan_Goessner) content.

But as you can easily leave that *math*, *vector graphics* and *research paper* stuff out, it may serve your non-academic publishing wishes also well. In this possible case you are invited to read on.
